
import 'package:flutter/material.dart';
import 'package:qhd_prevention/customWidget/danner_repain_item.dart';
import 'package:qhd_prevention/customWidget/department_picker.dart';
import 'package:qhd_prevention/customWidget/search_bar_widget.dart';
import 'package:qhd_prevention/pages/my_appbar.dart';


class CheckRecordListPage extends StatefulWidget {
  const CheckRecordListPage({super.key});

  @override
  _CheckRecordListPageState createState() => _CheckRecordListPageState();
}

class _CheckRecordListPageState extends State<CheckRecordListPage>
    with SingleTickerProviderStateMixin {
  late TabController _tabController;
  int _selectedTab = 0;

  // 模拟数据
  final List<NotificationItem> _notifications = List.generate(10, (i) {
    bool read = i % 3 == 0;
    String title = '测试数据标题标题 ${i + 1}';
    String time = '2025-06-${10 + i} 12:3${i}';
    return NotificationItem(title, time);
  });
  final List<Category> data = [
    Category(
      id: '1',
      title: '分类一',
      children: [
        Category(id: '1-1', title: '子项 1-1'),
        Category(id: '1-2', title: '子项 1-2'),
      ],
    ),
    Category(id: '2', title: '分类二'),
    Category(
      id: '3',
      title: '分类三',
      children: [
        Category(
          id: '3-1',
          title: '子项 3-1',
          children: [Category(id: '3-1-1', title: '子项 3-1-1')],
        ),
      ],
    ),
  ];
  final TextEditingController _searchController = TextEditingController();

  @override
  void initState() {
    super.initState();
    _tabController = TabController(length: 2, vsync: this);
    _tabController.addListener(() {
      if (!_tabController.indexIsChanging) {
        setState(() => _selectedTab = _tabController.index);
      }
    });
  }

  @override
  void dispose() {
    _tabController.dispose();
    super.dispose();
  }
  void _handleItemTap(NotificationItem item, int index) {
    print("点击了是: ${item.title}");

  }
  // 显示分类选择器
  void showCategoryPicker() {
    showModalBottomSheet(
      context: context,
      isScrollControlled: true,
      barrierColor: Colors.black54,
      backgroundColor: Colors.transparent,
      builder:
          (ctx) => DepartmentPicker(
        data: data,
        onSelected: (selectedId) {
          setState(() {});
        },
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: MyAppbar(
        title: "清单检查记录",

      ),
      body: SafeArea(
        child: Column(
          children: [
            // Tab bar
            TabBar(
              controller: _tabController,
              labelStyle: TextStyle(fontSize: 16),
              indicator: UnderlineTabIndicator(
                borderSide: BorderSide(width: 3.0, color: Colors.blue),
                insets: EdgeInsets.symmetric(horizontal: 100.0),
              ),
              labelColor: Colors.blue,
              unselectedLabelColor: Colors.grey,
              tabs: const [Tab(text: '已检查记录'), Tab(text: '超期未检查记录')],
            ),

            // Search bar
            Padding(
              padding: const EdgeInsets.all(10),
              child: SearchBarWidget(
                showResetButton: false,
                onInputTap: () {
                  showCategoryPicker();
                },
                hintText: "",
                isClickableOnly: true,
                onSearch: (text) {
                  print('----------');
                },
                controller: _searchController,
              ),
            ),

            // List
            Expanded(
              child: ListView.separated(
                itemCount: _notifications.length,
                separatorBuilder: (_, __) => const SizedBox(),
                itemBuilder: (context, index) {
                  NotificationItem item = _notifications[index];
                  return GestureDetector(
                    onTap: () => _handleItemTap(item, index),
                    child: DannerRepainItem(
                      title: '清单名称:测试的时候写的假数据',
                      showTitleIcon: false,
                      details: [
                        '清单类型：测试',
                        '排查周期：测试',
                        '包含检查项：3',
                        '负责人：是测试',
                        '起始时间：2025-6-20',
                        '',
                        '测试一下是否跳过时间'
                      ],
                      showBottomTags: false,

                    ),
                  );
                },
              ),
            ),
          ],
        ),
      ),
    );
  }


}

// 模拟数据模版
class NotificationItem {
  final String title;
  final String time;

  NotificationItem(this.title, this.time);
}
