import 'package:flutter/material.dart';
import 'package:qhd_prevention/customWidget/bottom_picker.dart';
import 'package:qhd_prevention/customWidget/department_picker.dart';
import '../../../tools/h_colors.dart';
import '/customWidget/custom_button.dart';

/// 自定义抽屉
class CustomRecordDrawer extends StatefulWidget {
  const CustomRecordDrawer({super.key});

  @override
  _CustomRecordDrawerState createState() => _CustomRecordDrawerState();
}

class _CustomRecordDrawerState extends State<CustomRecordDrawer> {
  // 四个选项的单选 index
  int _selectedOption = -1;
  // 已选择的分类 id
  String? _selectedCategoryId;
  // 检查人
  String? _selectedPerson;
  // 清单类型
  String? _selectedQDType;
  // 排查周期
  String? _selectedZQTime;

  // 新增：开始/结束时间
  DateTime? _startDate;
  DateTime? _endDate;

  @override
  Widget build(BuildContext context) {
    final List<Category> data = [
      Category(
        id: '1',
        title: '分类一1',
        children: [
          Category(id: '1-1', title: '子项 1-1'),
          Category(id: '1-2', title: '子项 1-2'),
        ],
      ),
      Category(id: '2', title: '分类二'),
      Category(
        id: '3',
        title: '分类三',
        children: [
          Category(id: '3-1', title: '子项 3-1', children: [
            Category(id: '3-1-1', title: '子项 3-1-1'),
          ]),
        ],
      ),
    ];

    Future<void> showCategoryPicker(int type) async {
      if (type == 1) {
        showModalBottomSheet(
          context: context,
          isScrollControlled: true,
          barrierColor: Colors.black54,
          backgroundColor: Colors.transparent,
          builder: (ctx) => DepartmentPicker(
            data: data,
            onSelected: (selectedId) {
              setState(() {
                _selectedCategoryId = selectedId;
              });
            },
          ),
        );
      } else if (type == 2) {
         final choice = await BottomPicker.show<String>(
           context,
           items: ['未知'],
           itemBuilder: (item) => Text(item, textAlign: TextAlign.center),
           initialIndex: 0,
         );
         if (choice != null) {
           // 用户点击确定并选择了 choice
           setState(() {
             _selectedPerson = choice;
           });
         }
      }else if (type == 3) {
        final choice = await BottomPicker.show<String>(
          context,
          items: ['日常', '综合', '专业', '季节性','节假日'],
          itemBuilder: (item) => Text(item, textAlign: TextAlign.center),
          initialIndex: 0,
        );
        if (choice != null) {
          setState(() {
            _selectedQDType = choice;
          });
        }
      }else if (type == 4) {
        final choice = await BottomPicker.show<String>(
          context,
          items: ['每日', '每周', '每旬', '每月', '每季', '半年', '每年'],
          itemBuilder: (item) => Text(item, textAlign: TextAlign.center),
          initialIndex: 0,
        );
        if (choice != null) {
          setState(() {
            _selectedZQTime = choice;
          });
        }
      }


    }

    Future<void> _pickStartDate() async {
      final now = DateTime.now();
      final picked = await showDatePicker(
        context: context,
        initialDate: _startDate ?? now,
        firstDate: DateTime(now.year - 5),
        lastDate: DateTime(now.year + 5),
      );
      if (picked != null) {
        setState(() {
          _startDate = picked;
          // 保证开始 <= 结束
          if (_endDate != null && _endDate!.isBefore(picked)) {
            _endDate = null;
          }
        });
      }
    }

    Future<void> _pickEndDate() async {
      final now = DateTime.now();
      final initial = _endDate ??
          (_startDate != null && _startDate!.isAfter(now)
              ? _startDate!
              : now);
      final picked = await showDatePicker(
        context: context,
        initialDate: initial,
        firstDate: _startDate ?? DateTime(now.year - 5),
        lastDate: DateTime(now.year + 5),
      );
      if (picked != null) {
        setState(() {
          _endDate = picked;
        });
      }
    }

    Widget _buildDatePickerBox({
      required String label,
      DateTime? date,
      required VoidCallback onTap,
    }) {
      final display = date != null
          ? "${date.year.toString().padLeft(4, '0')}-${date.month.toString().padLeft(2, '0')}-${date.day.toString().padLeft(2, '0')}"
          : label;
      return Expanded(
        child: GestureDetector(
          onTap: onTap,
          child: Container(
            height: 35,
            padding: const EdgeInsets.symmetric(horizontal: 5),
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(4),
              border: Border.all(color: Colors.grey.shade400),
              color: Colors.white,
            ),
            child: Row(
              children: [
                const Icon(Icons.calendar_today, size: 18, color: Colors.grey),
                const SizedBox(width: 6),
                Text(display, style: const TextStyle(fontSize: 14, color: Colors.black38)),
              ],
            ),
          ),
        ),
      );
    }

    return SafeArea(
      child: Padding(
        padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 20),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            const Text(
              "高级查询",
              style: TextStyle(fontSize: 18, fontWeight: FontWeight.bold),
            ),
            const Divider(height: 24, color: Colors.grey),

            // 分类筛选
            _buildDropdownBox(
              "检查部门",
              display: _selectedCategoryId ?? '请选择',
              onTap: () => showCategoryPicker(1),
            ),
            const SizedBox(height: 12),
            _buildDropdownBox(
              "检查人",
              display: _selectedPerson ?? '请选择',
              onTap: () => showCategoryPicker(2),
            ),
            const SizedBox(height: 12),
            _buildDropdownBox(
              "清单类型",
              display: _selectedQDType ?? '请选择',
              onTap: () => showCategoryPicker(3),
            ),
            const SizedBox(height: 12),
            _buildDropdownBox(
              "排查周期",
              display: _selectedZQTime ?? '请选择',
              onTap: () => showCategoryPicker(4),
            ),
            const SizedBox(height: 24),

            // 时间查询
            const Text(
              "时间查询",
              style: TextStyle(fontSize: 16, fontWeight: FontWeight.w500),
            ),
            const SizedBox(height: 12),

            // 开始时间 - 结束时间 —— //
            Row(
              children: [
                _buildDatePickerBox(
                  label: "开始时间",
                  date: _startDate,
                  onTap: _pickStartDate,
                ),
                const SizedBox(width: 5),
                const Text("—", style: TextStyle(fontSize: 8)),
                const SizedBox(width: 5),
                _buildDatePickerBox(
                  label: "结束时间",
                  date: _endDate,
                  onTap: _pickEndDate,
                ),
              ],
            ),

            const Spacer(),

            // 底部按钮
            Row(
              children: [
                Expanded(
                  flex: 1,
                  child: CustomButton(
                    text: "重置",
                    backgroundColor: h_backGroundColor(),
                    textStyle: const TextStyle(color: Colors.black45),
                    onPressed: () {
                      setState(() {
                        _selectedOption = -1;
                        _selectedCategoryId = null;
                        _startDate = null;
                        _endDate = null;
                      });
                    },
                  ),
                ),
                const SizedBox(width: 12),
                Expanded(
                  flex: 2,
                  child: CustomButton(
                    text: "完成",
                    backgroundColor: Colors.blue,
                    onPressed: () {
                      // TODO: 提交筛选条件，包括 _startDate、_endDate
                    },
                  ),
                ),
              ],
            ),
          ],
        ),
      ),
    );
  }

  Widget _buildDropdownBox(String title,
      {required String display, required VoidCallback onTap}) {
    return GestureDetector(
      onTap: onTap,
      child: Container(
        height: 48,
        padding: const EdgeInsets.symmetric(horizontal: 12),
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(4),
          border: Border.all(color: Colors.grey.shade400),
          color: Colors.white,
        ),
        child: Row(
          children: [
            Text(title, style: const TextStyle(fontSize: 14)),
            const Spacer(),
            Row(
              children: [
                Text(display),
                const Icon(Icons.arrow_drop_down, color: Colors.grey),
              ],
            ),
          ],
        ),
      ),
    );
  }
}
